summaryrefslogtreecommitdiff
path: root/board/cr50/usb_i2c.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/cr50/usb_i2c.c')
-rw-r--r--board/cr50/usb_i2c.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/board/cr50/usb_i2c.c b/board/cr50/usb_i2c.c
index 64f9cdeaaa..39e4a4f27c 100644
--- a/board/cr50/usb_i2c.c
+++ b/board/cr50/usb_i2c.c
@@ -65,10 +65,10 @@ static void ina_connect(void)
GWRITE(PINMUX, DIOB0_SEL, GC_PINMUX_I2C0_SCL_SEL);
/*
* Initialize the i2cm module after the INAs are powered and the signal
* lines are connected.
*/
- i2cm_init();
+ i2cc_init();
usb_i2c_enabled = true;
}
@@ -65,10 +65,10 @@ static void ina_connect(void)
GWRITE(PINMUX, DIOB0_SEL, GC_PINMUX_I2C0_SCL_SEL);
/*
- * Initialize the i2cm module after the INAs are powered and the signal
+ * Initialize the i2cc module after the INAs are powered and the signal
* lines are connected.
*/